@@ -8,7 +8,6 @@ import glob
 import logging
 import os
 import re
-import time
 import thread
 
 from fabric.api import env, settings
@@ -233,11 +232,12 @@ def build_run(cmd, files=None, all_files=True, async=False, sync_first=False, ke
                     # If keep alive is a function, call it
                     keep_alive(command, *a, **kws)
                 else:
+                    import time
                     # Else, it hsould be an integer
                     time.sleep(keep_alive)
 
     run_fn = r
-    if keep_alive > 0:
+    if keep_alive:
         register_keep_alive()
         run_fn = keep_alive_fn
 
@@ -297,6 +297,7 @@ def keep_alive():
     """
     Simple runtime loop to keep application alive
     """
+    import time
     logger.debug("Running keep-alive function")
     while True:
         time.sleep(1)
